json_factory_annotation library

The entrypoint for the json_factory_annotation package.

This package provides annotations for marking model classes to be included in centralized, type-safe JSON factories. Use jsonModel to annotate your model classes and enable automatic discovery and parsing support.

Classes

JsonModel
Annotation for marking a class to be included in the auto-generated JsonFactory.

Constants

jsonModel → const JsonModel
Constant instance of JsonModel annotation.